.. _io.openmx:

OpenMX
======

.. module:: sisl.io.openmx

.. autosummary::
   :toctree: generated/

   omxSileOpenMX - input file
   mdSileOpenMX - moleculer dynamics file


.. autosummary::
   :toctree: generated/
   :hidden:

   SileOpenMX
   SileCDFOpenMX
   SileBinOpenMX

